==> nextcloud-app-deck-1%3A1.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ro.js <==
OC.L10N.register(
    "deck",
    {
    "Upcoming cards" : "Carduri viitoare",
    "Personal" : "Personal",
    "%s on %s" : "%s pe %s",
    "Finished" : "Finalizat",
    "Later" : "Mai târziu",
    "copy" : "copiază",
    "Done" : "Realizat",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Card not found" : "Card negăsit ",
    "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
    "Add board" : "Adaugă panou",
    "Cancel" : "Anulează",
    "Close" : "Închide",
    "File already exists" : "Fișierul există deja",
    "Archived cards" : "Carduri arhivate",
    "Add list" : "Adaugă listă ",
    "Filter by tag" : "Filtrare după etichetă",
    "Filter by assigned user" : "Filtrează după utilizatorul atribuit",
    "Unassigned" : "Nealocat",
    "Filter by due date" : "Filtrează după data scadentă",
    "Overdue" : "Termen depășit",
    "Next 7 days" : "Următorele 7 zile",
    "Next 30 days" : "Următorele 30 zile",
    "No due date" : "Fără dată limită",
    "Details" : "Detalii",
    "Sharing" : "Partajare",
    "Tags" : "Etichete",
    "Undo" : "Anulează ultima acțiune",
    "Can edit" : "Poate edita",
    "Can share" : "Can share",
    "Owner" : "Proprietar",
    "Delete" : "Șterge",
    "Transfer" : "Transfer",
    "Delete list" : "Șterge lista",
    "Edit" : "Editează",
    "Download" : "Descărcare",
    "Attachments" : "Atașamente ",
    "Comments" : "Comentarii",
    "Modified" : "Modificat",
    "Due date" : "Data scadenței",
    "Today" : "Azi",
    "Tomorrow" : "Mâine",
    "Next week" : "Saptămâna următoare",
    "Next month" : "Luna următoare",
    "Save" : "Salvează",
    "Reply" : "Răspunde",
    "Update" : "Actualizare",
    "Description" : "Descriere",
    "Edit description" : "Editează descriere",
    "(group)" : "(grup)",
    "Move card" : "Mută card",
    "Archive card" : "Arhivează card",
    "Delete card" : "Șterge card",
    "seconds ago" : "secunde în urmă",
    "Archived boards" : "Panouri arhivate",
    "Shared with you" : "Partajat cu tine",
    "Edit board" : "Editează panou",
    "Clone board" : "Clonează panou",
    "Archive board" : "Arhivează panou",
    "No notifications" : "Nu sunt notificări",
    "Delete board" : "Șterge panou",
    "No reminder" : "Fără mementouri",
    "Share" : "Partajează",
    "This week" : "Săptămâna asta"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-app-deck-1%3A1.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ro.js <==
OC.L10N.register(
    "deck",
    {
    "Upcoming cards" : "Carduri viitoare",
    "Personal" : "Personal",
    "%s on %s" : "%s pe %s",
    "Finished" : "Finalizat",
    "Later" : "Mai târziu",
    "copy" : "copiază",
    "Done" : "Realizat",
    "The file was uploaded" : "Fișierul a fost încărcat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "The file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Could not write file to disk" : "Nu s-a putut scrie fișierul pe disc",
    "A PHP extension stopped the file upload" : "O extensie PHP a oprit încărcarea fișierelor",
    "Card not found" : "Card negăsit ",
    "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
    "Add board" : "Adaugă panou",
    "Cancel" : "Anulează",
    "Close" : "Închide",
    "File already exists" : "Fișierul există deja",
    "Archived cards" : "Carduri arhivate",
    "Add list" : "Adaugă listă ",
    "Filter by tag" : "Filtrare după etichetă",
    "Filter by assigned user" : "Filtrează după utilizatorul atribuit",
    "Unassigned" : "Nealocat",
    "Filter by due date" : "Filtrează după data scadentă",
    "Overdue" : "Termen depășit",
    "Next 7 days" : "Următorele 7 zile",
    "Next 30 days" : "Următorele 30 zile",
    "No due date" : "Fără dată limită",
    "Details" : "Detalii",
    "Sharing" : "Partajare",
    "Tags" : "Etichete",
    "Undo" : "Anulează ultima acțiune",
    "Can edit" : "Poate edita",
    "Can share" : "Can share",
    "Owner" : "Proprietar",
    "Delete" : "Șterge",
    "Transfer" : "Transfer",
    "Delete list" : "Șterge lista",
    "Edit" : "Editează",
    "Download" : "Descărcare",
    "Attachments" : "Atașamente ",
    "Comments" : "Comentarii",
    "Modified" : "Modificat",
    "Due date" : "Data scadenței",
    "Today" : "Azi",
    "Tomorrow" : "Mâine",
    "Next week" : "Saptămâna următoare",
    "Next month" : "Luna următoare",
    "Save" : "Salvează",
    "Reply" : "Răspunde",
    "Update" : "Actualizare",
    "Description" : "Descriere",
    "Edit description" : "Editează descriere",
    "(group)" : "(grup)",
    "Move card" : "Mută card",
    "Archive card" : "Arhivează card",
    "Delete card" : "Șterge card",
    "seconds ago" : "secunde în urmă",
    "Archived boards" : "Panouri arhivate",
    "Shared with you" : "Partajat cu tine",
    "Edit board" : "Editează panou",
    "Clone board" : "Clonează panou",
    "Archive board" : "Arhivează panou",
    "No notifications" : "Nu sunt notificări",
    "Delete board" : "Șterge panou",
    "No reminder" : "Fără mementouri",
    "Share" : "Partajează",
    "This week" : "Săptămâna asta"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
